/**
 * Created by ruckola on 9-12-16.
 *
 * These tests need a default command class in the ./bin/commands directory in order
 * to pass successfully.
 */
const assert = require('chai').assert;
const CommandFactory = require('../../bin/core/commandFactory');
const fs = require('fs');
const path = require('path');
const Helper = require("../../bin/core/helper");

describe("Test suite for (static) class CommandFactory", function () {

    it("The getCommand method should trow an error if parameter 'action' isn't of type string.", function () {

        function wrongActionType() {
            var action = { foo: 'bar' };
            var cmd = CommandFactory.getCommand(action);
            return cmd;
        }

        assert.throws(wrongActionType, Error);
    });

    it("The getCommand method should trow an error if parameter 'action' contains illegal characters.", function () {

        function wrongActionType() {
            var action = 'd efault';
            var cmd = CommandFactory.getCommand(action);
            return cmd;
        }

        assert.throws(wrongActionType, Error);
    });


    it('The absolute path should be an existing directory', function () {

        var action = 'testCommand1';
        var cfg = Helper.getModConfig(true);
        var relPath = cfg.userCommandsRootDir;
        var dir = Helper.getAbsolutPath(relPath);
        var cmd = CommandFactory.getCommand(action, dir);

        assert.equal(fs.existsSync(cmd.props.absolutePath), true);
    });

    it("The getCommand method should trow an error if the absolutePath doesn't exist.", function () {

        function nonExistingAction() {
            var action = 'nonExistingCommand';
            var cmd = CommandFactory.getCommand(action);
            return cmd;
        }

        assert.throws(nonExistingAction, Error);
    });

    it("The getCommand method should return a object of type command.", function () {

        function checkCmdType() {
            var action = 'testCommand1';
            var cfg = Helper.getModConfig(true);
            var relPath = cfg.userCommandsRootDir;
            var dir = Helper.getAbsolutPath(relPath);
            var cmd = CommandFactory.getCommand(action, dir);
            return cmd;
        }
        var c = checkCmdType();

        assert.equal(c instanceof Command, true);
    });


    it("The getCommand method should return the build-in 'macro' command for action 'macro'.", function () {
        
            var cmd = CommandFactory.getCommand("macro","foo");
            assert.equal(cmd instanceof Command, true);
        
    })

})